import { defineStore } from 'pinia'
import pinia from '~src/store/init'
import appConfig from '~src/config/app'
import logoIcon from '~src/assets/logo/icon.png'
import logoName from '~src/assets/logo/name.png'
import {
    clearStoreAll, getStore, removeRefreshToken, removeToken,
    setRefreshToken, setStore, setToken,
} from 'hc-vue3-ui'

export const useAppStore = defineStore('main', {
    state: () => ({
        //系统信息
        title: getStore('title') || appConfig.title,
        logoIcon: getStore('logoIcon') || logoIcon,
        logoName: getStore('logoName') || logoName,
        //主题信息
        theme: getStore('theme') || appConfig.theme, //用户可选择类型：auto,light, dark
        themeVal: getStore('themeVal') || '', //实际主题：light, dark
        color: getStore('color') || appConfig.color,
        //用户信息
        token: getStore('token') || '',
        refreshToken: getStore('refreshToken') || '',
        tenantId: getStore('tenantId') || '',
        userInfo: getStore('userInfo') || {},
        //菜单信息
        menus: getStore('menus') || [],
        buttons: getStore('buttons') || {},
        homeUrl: getStore('homeUrl'), //首页路由
        //项目合同段数据
        projectContract: getStore('projectContract') || [],
        projectInfo: getStore('projectInfo') || {},
        contractInfo: getStore('contractInfo') || {},
        projectId: getStore('projectId') || '',
        contractId: getStore('contractId') || '',
        //其他配置信息
        bubble: getStore('bubble') || false,
        isCollapse: getStore('isCollapse') || false, //菜单折叠
        dragModalSortTop: [], //拖拽弹窗排序
        barMenuName: '',
        isSource: getStore('isSource') || '', //来源
    }),
    getters: {
        //系统信息
        getTitle: state => state.title,
        getLogoIcon: state => state.logoIcon,
        getLogoName: state => state.logoName,
        //主题信息
        getTheme: state => state.theme,
        getThemeVal: state => state.themeVal,
        getColor: state => state.color,
        //用户信息
        getToken: state => state.token,
        getRefreshToken: state => state.refreshToken,
        getTenantId: state => state.tenantId,
        getUserInfo: state => state.userInfo,
        //菜单信息
        getMenus: state => state.menus,
        getButtons: state => state.buttons,
        getHomeUrl: state => state.homeUrl,
        //项目合同段数据
        getProjectContract: state => state.projectContract,
        getProjectInfo: state => state.projectInfo,
        getContractInfo: state => state.contractInfo,
        getProjectId: state => state.projectId,
        getContractId: state => state.contractId,
        //其他配置信息
        getBubble: state => state.bubble,
        getCollapse: state => state.isCollapse,
        getDragModalSortTop: state => state.dragModalSortTop,
        getIsSource: state => state.isSource,
    },
    actions: {
        //系统信息
        setTitle(value) {
            this.title = value
            setStore('title', value)
        },
        setLogoIcon(value) {
            this.logoIcon = value
            setStore('logoIcon', value)
        },
        setLogoName(value) {
            this.logoName = value
            setStore('logoName', value)
        },
        //主题信息
        setTheme(value) {
            this.theme = value
            setStore('theme', value)
        },
        setThemeVal(value) {
            this.themeVal = value
            setStore('themeVal', value)
        },
        setColor(value) {
            this.color = value
            setStore('color', value)
        },
        //用户信息
        setTokenVal(value) {
            this.token = value
            setToken(value)
            setStore('token', value)
        },
        setRefreshTokenVal(value) {
            this.refreshToken = value
            setRefreshToken(value)
            setStore('refreshToken', value)
        },
        setTenantId(value) {
            this.tenantId = value
            setStore('tenantId', value)
        },
        setUserInfo(value) {
            this.userInfo = value
            setStore('userInfo', value)
        },
        //菜单信息
        setMenus(value) {
            this.menus = value
            setStore('menus', value)
        },
        setButtons(value) {
            this.buttons = value
            setStore('buttons', value)
        },
        getButtonsVal(value) {
            return this.buttons[value] || false
        },
        setHomeUrl(value) {
            this.homeUrl = value
            setStore('homeUrl', value)
        },
        //项目合同段数据
        setProjectContract(value) {
            this.projectContract = value
            setStore('projectContract', value)
        },
        setProjectInfo(value) {
            this.projectInfo = value
            setStore('projectInfo', value)
        },
        setContractInfo(value) {
            this.contractInfo = value
            setStore('contractInfo', value)
        },
        setProjectId(value) {
            this.projectId = value
            setStore('projectId', value)
        },
        setContractId(value) {
            this.contractId = value
            setStore('contractId', value)
        },
        //其他配置信息
        setBubble(value) {
            this.bubble = value
            setStore('bubble', value)
        },
        setCollapse(value) { //菜单折叠
            this.isCollapse = value
            setStore('isCollapse', value)
        },
        setDragModalSortTop(value) {
            this.dragModalSortTop = value
        },
        setIsSource(value) {
            this.isSource = value
            setStore('isSource', value)
        },
        //清除缓存和token
        clearStoreData() {
            //清除状态
            this.title = null
            this.logoIcon = null
            this.logoName = null
            this.token = null
            this.refreshToken = null
            this.tenantId = null
            this.userInfo = null
            this.menus = null
            this.buttons = null
            this.projectContract = null
            this.projectInfo = null
            this.contractInfo = null
            this.projectId = null
            this.contractId = null
            this.isCollapse = false
            this.dragModalSortTop = []
            this.isSource = ''
            //清除缓存
            clearStoreAll()
            removeToken()
            removeRefreshToken()
        },
    },
})

export default function useUserStoreWidthOut() {
    return useAppStore(pinia)
}
